//
//  POKKMoatTrackerDelegate.h
//  POKKMoatMobileAppKit
//
//  Created by Moat 740 on 3/27/17.
//  Copyright © 2017 Moat. All rights reserved.
//

#import "POKKMoatAdEventType.h"

#ifndef POKKMoatTrackerDelegate_h
#define POKKMoatTrackerDelegate_h

typedef enum : NSUInteger {
    POKKMoatStartFailureTypeNone = 0, //Default none value
    POKKMoatStartFailureTypeActive,   //The tracker was already active
    POKKMoatStartFailureTypeRestart,  //The tracker was stopped already
    POKKMoatStartFailureTypeBadArgs,  //The arguments provided upon initialization or startTracking were invalid.
} POKKMoatStartFailureType;

@class POKKMoatBaseTracker;
@class POKKMoatBaseVideoTracker;

@protocol POKKMoatTrackerDelegate <NSObject>

@optional

/**
 Notifies delegate that the tracker has started tracking.
 */

- (void)trackerStartedTracking:(POKKMoatBaseTracker *)tracker;

/**
 Notifies delegate that the tracker has stopped tracking.
 */

- (void)trackerStoppedTracking:(POKKMoatBaseTracker *)tracker;

/**
 Notifies delegate that the tracker failed to start.
 
 @param type Type of startTracking failure.
 @param reason A human readable string on why the tracking failed.
 */

- (void)tracker:(POKKMoatBaseTracker *)tracker failedToStartTracking:(POKKMoatStartFailureType)type reason:(NSString *)reason;

@end

#pragma mark

@protocol POKKMoatVideoTrackerDelegate <NSObject>

@optional

/**
 Notifies delegate an ad event type is being dispatched (i.e. start, pause, quarterly events).
 
 @param adEventType The type of event fired.
 */
- (void)tracker:(POKKMoatBaseVideoTracker *)tracker sentAdEventType:(POKKMoatAdEventType)adEventType;

@end

#endif /* POKKMoatTrackerDelegate_h */
